suffixarray: rename Data() -> Bytes()

R=rsc
CC=golang-dev
https://golang.org/cl/3540042
diff --git a/src/pkg/index/suffixarray/suffixarray.go b/src/pkg/index/suffixarray/suffixarray.go
index 0a8d9e2..9dec943 100644
--- a/src/pkg/index/suffixarray/suffixarray.go
+++ b/src/pkg/index/suffixarray/suffixarray.go
@@ -49,10 +49,10 @@
 }
 
 
 // Data returns the data over which the index was created.
 // It must not be modified.
 //
-func (x *Index) Data() []byte {
+func (x *Index) Bytes() []byte {
 	return x.data
 }
@@ -49,10 +49,10 @@
 
 
-// Data returns the data over which the index was created.
+// Bytes returns the data over which the index was created.
 // It must not be modified.
 //